@@ -18,39 +18,26 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+import pygtk
+pygtk.require('2.0')
+import gtk
+
 from jhbuild.commands import Command, register_command
 import jhbuild.frontends
-from jhbuild.frontends.gtkui import Configuration
 
 
 class cmd_gui(Command):
-    doc = _('Build targets from a GUI app')
+    doc = N_('Build targets from a GUI app')
 
     name = 'gui'
     usage_args = ''
 
-    def run(self, config, options, args):
+    def run(self, config, options, args, help=None):
         # request GTK build script.
         config.buildscript = 'gtkui'
 
-        configuration = Configuration(config, args)
-        (module_list, start_at,
-         run_autogen, cvs_update, no_build) = configuration.run()
-
-        if start_at:
-            while module_list and module_list[0].name != start_at:
-                del module_list[0]
-
-        if run_autogen:
-            config.alwaysautogen = True
-        elif not cvs_update:
-            config.nonetwork = True
-
-        if no_build:
-            config.nobuild = True
-
-        if module_list != None:
-            build = jhbuild.frontends.get_buildscript(config, module_list)
-            return build.build()
+        build = jhbuild.frontends.get_buildscript(config)
+        build.show()
+        gtk.main()
 
 register_command(cmd_gui)
