@@ -64,11 +64,12 @@ class cmd_tinderbox(Command):
                         help=_('build even if policy says not to'))
             ])
 
-    def run(self, config, options, args):
-        extra_config = {'buildscript': 'tinderbox'}
-        if options.force_policy:
-            extra_config = {'build_policy': 'all'}
+    def run(self, config, options, args, help=None):
         config.set_from_cmdline_options(options)
+        config.buildscript = 'tinderbox'
+
+        if options.outputdir is not None:
+            config.tinderbox_outputdir = options.outputdir
 
         if not config.tinderbox_outputdir:
             raise UsageError(_('output directory for tinderbox build not specified'))
