@@ -64,14 +64,15 @@ class AppWindow(gtk.Window, buildscript.BuildScript):
         gtk.Window.__init__(self)
         self.set_resizable(False)
         theme = gtk.icon_theme_get_default()
-        gtk.window_set_default_icon_list(
-                theme.load_icon('applications-development', 16, ()),
-                theme.load_icon('applications-development', 24, ()),
-                theme.load_icon('applications-development', 32, ()),
-                theme.load_icon('applications-development', 48, ()),
-                theme.load_icon('applications-development', 64, ()),
-                theme.load_icon('applications-development', 128, ())
-                )
+        if theme.has_icon('applications-development'):
+            gtk.window_set_default_icon_list(
+                    theme.load_icon('applications-development', 16, ()),
+                    theme.load_icon('applications-development', 24, ()),
+                    theme.load_icon('applications-development', 32, ()),
+                    theme.load_icon('applications-development', 48, ()),
+                    theme.load_icon('applications-development', 64, ()),
+                    theme.load_icon('applications-development', 128, ())
+                    )
         self.set_title('JHBuild')
 
         self.module_set = jhbuild.moduleset.load(config)
@@ -400,8 +401,12 @@ class AppWindow(gtk.Window, buildscript.BuildScript):
         self.error_resolution_model.append(
                 (_('Give up on module'), 'fail'))
         for altphase in altphases:
+            try:
+                altphase_label = _(getattr(getattr(module, 'do_' + altphase), 'label'))
+            except AttributeError:
+                altphase_label = altphase
             self.error_resolution_model.append(
-                    (_('Go to stage %s') % altphase, altphase))
+                    (_('Go to phase "%s"') % altphase_label, altphase))
         self.error_resolution_model.append(('', ''))
         self.error_resolution_model.append(
                 (_('Open Terminal'), 'shell'))
