@@ -128,12 +128,13 @@ class TerminalBuildScript(buildscript.BuildScript):
         module_pos = '[' + format_str % module_num + '/' + format_str % len(self.modulelist) + ']'
 
         output = '%s %s %s%s%s' % (progress_bar, module_pos, t_bold, message, t_reset)
-        if len(output) > columns:
-            output = output[:columns]
+        text_width = len(output) - (len(t_bold) + len(t_reset))
+        if text_width > columns:
+            output = output[:columns+len(t_bold)] + t_reset
         else:
-            output += ' ' * (columns-len(output))
+            output += ' ' * (columns-text_width)
 
-        sys.stdout.write(output + '\r')
+        sys.stdout.write('\r'+output)
         if self.is_end_of_build:
             sys.stdout.write('\n')
         sys.stdout.flush()
@@ -295,6 +296,7 @@ class TerminalBuildScript(buildscript.BuildScript):
                 uprint('  [%d] %s' % (i, _('Go to phase "%s"') % altphase_label))
                 i += 1
             val = raw_input(uencode(_('choice: ')))
+            val = udecode(val)
             val = val.strip()
             if val == '1':
                 return phase
@@ -327,6 +329,7 @@ class TerminalBuildScript(buildscript.BuildScript):
                     needs_confirmation = False
                 if needs_confirmation:
                     val = raw_input(uencode(_('Type "yes" to confirm the action: ')))
+                    val = udecode(val)
                     val = val.strip()
                     if val.lower() in ('yes', _('yes').lower()):
                         return selected_phase
