@@ -37,7 +37,11 @@ from jhbuild.utils import httpcache
 from jhbuild.utils.cmds import get_output
 from jhbuild.modtypes.testmodule import TestModule
 
-__all__ = ['load', 'load_tests']
+__all__ = ['load', 'load_tests', 'get_default_repo']
+
+_default_repo = None
+def get_default_repo():
+    return _default_repo
 
 class ModuleSet:
     def __init__(self, config = None):
@@ -57,8 +61,7 @@ class ModuleSet:
                     logging.info(_('fixed case of module \'%(orig)s\' to \'%(new)s\'') % {
                             'orig': module_name, 'new': module})
                 return self.modules[module]
-        print "Couldn't find the specified module: %s" % module_name
-        sys.exit(2)
+        raise KeyError(module_name)
 
     def get_module_list(self, seed, skip=[], tags=[], ignore_cycles=False,
                 ignore_suggests=False, include_optional_modules=False,
@@ -284,11 +287,17 @@ def load(config, uri=None):
         modulesets = [ config.moduleset ]
     ms = ModuleSet(config = config)
     for uri in modulesets:
-        if '/' not in uri and not os.path.isfile(uri):
-            if config.modulesets_dir and config.nonetwork or config.use_local_modulesets:
+        if os.path.isabs(uri):
+            pass
+        elif config.modulesets_dir and config.nonetwork or config.use_local_modulesets:
+            if os.path.isfile(os.path.join(config.modulesets_dir,
+                                           uri + '.modules')):
                 uri = os.path.join(config.modulesets_dir, uri + '.modules')
-            else:
-                uri = 'http://git.gnome.org/browse/jhbuild/plain/modulesets/%s.modules' % uri
+            elif os.path.isfile(os.path.join(config.modulesets_dir, uri)):
+                uri = os.path.join(config.modulesets_dir, uri)
+        elif not urlparse.urlparse(uri)[0]:
+            uri = 'http://git.gnome.org/browse/jhbuild/plain/modulesets' \
+                  '/%s.modules' % uri
         try:
             ms.modules.update(_parse_module_set(config, uri).modules)
         except xml.parsers.expat.ExpatError, e:
@@ -408,6 +417,11 @@ def _parse_module_set(config, uri):
             module.config = config
             moduleset.add(module)
 
+    # keep default repository around, used when creating automatic modules
+    global _default_repo
+    if default_repo:
+        _default_repo = repositories[default_repo]
+
     return moduleset
 
 def warn_local_modulesets(config):
